@@ -5,8 +5,8 @@
 
 /*****************************************************************************/
 /*  cdavl.c - CUI disk allocation viewer                                     */
-/*  Copyright: Copyright (c) Hitachi, Ltd. 2004-2005                         */
-/*             Authors: Yumiko Sugita (sugita@sdl.hitachi.co.jp),            */
+/*  Copyright: Copyright (c) Hitachi, Ltd. 2004-2007                         */
+/*             Authors: Yumiko Sugita (yumiko.sugita.yf@hitachi.com),        */
 /*                      Satoshi Fujiwara (sa-fuji@sdl.hitachi.co.jp)         */
 /*                                                                           */
 /*  This program is free software; you can redistribute it and/or modify     */
@@ -114,7 +114,7 @@ void printSuperBlock(t_e2info* fs) {
 	PRINT4("s_feature_incompat:       ", sb->s_feature_incompat);
 	PRINT4("s_feature_ro_compat:      ", sb->s_feature_ro_compat);
 	printf("s_uuid:\n");
-	uDumpN(sb->s_uuid, 16);
+	uDumpN((char*)sb->s_uuid, 16);
 	PRINTS("s_volume_name:            ", sb->s_volume_name, 16);
 	PRINTS("s_last_mounted:           ", sb->s_last_mounted, 64);
 	PRINT4("s_algorithm_usage_bitmap: ", sb->s_algorithm_usage_bitmap);
@@ -122,14 +122,14 @@ void printSuperBlock(t_e2info* fs) {
 	PRINT1("s_prealloc_dir_blocks:    ", sb->s_prealloc_dir_blocks);
 	if (sb->s_feature_compat & EXT3_FEATURE_COMPAT_HAS_JOURNAL) {
 		printf("s_journal_uuid:\n");
-		uDumpN(sb->s_journal_uuid, 16);
+		uDumpN((char*)sb->s_journal_uuid, 16);
 		PRINT4("s_journal_inum:           ", sb->s_journal_inum);
 		PRINT4("s_journal_dev:            ", sb->s_journal_dev);
 		PRINT4("s_last_orphan:            ", sb->s_last_orphan);
 	}
 #ifdef NEW_KERNEL
 	printf("s_hash_seed:\n");
-	uDumpN(sb->s_hash_seed, 4);
+	uDumpN((char*)sb->s_hash_seed, 4);
 	PRINT1("s_def_hash_version:       ", sb->s_def_hash_version);
 	PRINT4("s_default_mount_opts:     ", sb->s_default_mount_opts);
 	PRINT4("s_first_meta_bg:          ", sb->s_first_meta_bg);
@@ -944,7 +944,7 @@ EXIT:
 	else
 		bn = 0;
 	if (prog_c->verbose_level >= 1)
-		sprintf(xattr, ", xattr: %u", i_info.xattrs);
+		sprintf((char*)xattr, ", xattr: %u", i_info.xattrs);
 	else
 		xattr[0] = '\0';
 	if (is_fragment) {
